@@ -24,3 +24,10 @@ class Test2(unittest.TestCase):
 
     def test_2(self):
         assert self.x
+
+
+class Test3(Test):
+    # this has class setup by virtue of inheritting from Test
+
+    def test_3(self):
+        assert self.x
